@@ -22,9 +22,6 @@ class EasyViewer(neuroglancer.Viewer):
     def _repr_html_(self):
         return '<a href="%s" target="_blank">Viewer</a>' % self.as_url()
 
-    def set_source_url(self, ngl_url):
-        self.ngl_url = neuroglancer.set_server_bind_address(ngl_url)
-
     def load_url(self, url):
         """Load neuroglancer compatible url and updates viewer state
 
@@ -84,6 +81,18 @@ class EasyViewer(neuroglancer.Viewer):
         with self.txn() as s:
             s.voxel_size = resolution
 
+    def add_contrast_shader(self, layer_name):
+        shader_text = "#uicontrol float black slider(min=0, max=1, default=0.4)\n#uicontrol float white slider(min=0, max=1, default=0.65)\nfloat rescale(float value) {\n  return (value - black) / (white - black);\n}\nvoid main() {\n  float val = toNormalized(getDataValue());\n  if (val < black) {\n    emitRGB(vec3(0,0,0));\n  } else if (val > white) {\n    emitRGB(vec3(1.0, 1.0, 1.0));\n  } else {\n    emitGrayscale(rescale(val));\n  }\n}\n"
+        self._update_layer_shader(layer_name, shader_text)
+
+    def _update_layer_shader(self, layer_name, shader_text):
+        with self.txn() as s:
+            s.layers[layer_name]._json_data['shader'] = shader_text
+
+    def set_state_server(self, state_server):
+        with self.txn() as s:
+            s._json_data['jsonStateServer'] = state_server
+
     def add_annotation_layer(self, layer_name=None, color=None,
                              linked_segmentation_layer=None, filter_by_segmentation=True,
                              tags=None):
@@ -207,7 +216,7 @@ class EasyViewer(neuroglancer.Viewer):
 
     def as_url(self, prefix=None, as_html=False, link_text='Neuroglancer link'):
         if prefix is None:
-            prefix = utils.default_static_content_source
+            prefix = utils.default_neuroglancer_base
         ngl_url = neuroglancer.to_url(self.state, prefix=prefix)
         if as_html:
             return '<a href="{}" target="_blank">{}</a>'.format(ngl_url, link_text)
